pub fn attach_journal_subscriber_from(
opts: &AttachOptions,
lane: &str,
start_pos: u64,
) -> Result<ShmJournalSubscriber, BackingError>Expand description
Attach to a journal subscriber starting at an explicit position.
pub fn attach_journal_subscriber_from(
opts: &AttachOptions,
lane: &str,
start_pos: u64,
) -> Result<ShmJournalSubscriber, BackingError>Attach to a journal subscriber starting at an explicit position.