pub fn attach_journal_subscriber_tail(
opts: &AttachOptions,
lane: &str,
) -> Result<ShmJournalSubscriber, BackingError>Expand description
Attach to a journal subscriber starting at the current tail (safe-by-default).
This avoids unintentionally replaying old data unless an operator explicitly requests it
via attach_journal_subscriber_from.