ShmEventsMpscRx

Struct ShmEventsMpscRx 

pub struct ShmEventsMpscRx { /* private fields */ }
SHM-backed events-chain RX lane (MPSC) over EventsChainLayout4.

Implementations

Source

impl ShmEventsMpscRx

pub fn try_recv_with<F, R, E>( &self, f: F, ) -> Result<Option<R>, RecvWithError<E>>
where F: FnOnce(&[u8]) -> Result<R, E>,

Receive by borrowing the slot bytes for the duration of f.

pub fn try_recv_slot(&self) -> Result<Option<EventsSlot>, Error>

Receive a message as an owned slot handle (for slot forwarding).