pub struct SingleRingV1 {
pub shards: u32,
pub ordering: OrderingV1,
pub producer: SingleRingProducerV1,
pub scheduling: SingleRingSchedulingV1,
pub shard_key: ShardKeyV1,
pub stages: Vec<StageV1>,
}Expand description
SingleRing v1 spec: a stage DAG executed over one sequenced ring.
Stages are referenced by index. Dependencies are expressed as a list of stage indices.
v1 simplification: stages must be listed in topological order (all dependencies must reference a stage with a smaller index).
Fields
shards: u32Number of PerKey shards (rings) to run.
1 means a single unsharded ring.
ordering: OrderingV1Requested ordering semantics.
Note: OrderingV1::Strict is only valid when shards == 1 in v1.
producer: SingleRingProducerV1Requested producer model.
scheduling: SingleRingSchedulingV1Requested scheduling/consumption model.
shard_key: ShardKeyV1Deterministic sharding key extraction.
Only used when shards > 1.
stages: Vec<StageV1>Stages in execution order.