pub struct ShmEventsMpscRx { /* private fields */ }Expand description
SHM-backed events-chain RX lane (MPSC) over EventsChainLayout4.
Implementations
Sourceimpl ShmEventsMpscRx
impl ShmEventsMpscRx
Sourcepub fn try_recv_with<F, R, E>(
&self,
f: F,
) -> Result<Option<R>, RecvWithError<E>>
pub fn try_recv_with<F, R, E>( &self, f: F, ) -> Result<Option<R>, RecvWithError<E>>
Receive by borrowing the slot bytes for the duration of f.
Sourcepub fn try_recv_slot(&self) -> Result<Option<EventsSlot>, Error>
pub fn try_recv_slot(&self) -> Result<Option<EventsSlot>, Error>
Receive a message as an owned slot handle (for slot forwarding).