pub type ThreadInitHook = Arc<dyn Fn(&ThreadInitContext) -> Result<(), ExecError> + Send + Sync + 'static>;Expand description
Hook invoked at the start of an executor thread.
If the hook returns an error, role execution fails.
Aliased Type
pub struct ThreadInitHook { /* private fields */ }